<?php
/**
 * Moun10 Pro Customizer.
 *
 * @package Theme Palace
 * @subpackage Moun10 Pro
 * @since Moun10 Pro 1.0.0
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function moun10_pro_customize_register( $wp_customize ) {
	$options = moun10_pro_get_theme_options();

	// Load custom control functions.
	require get_template_directory() . '/inc/customizer/custom-controls.php';

	// Load customize active callback functions.
	require get_template_directory() . '/inc/customizer/active-callback.php';

	// Load partial callback functions.
	require get_template_directory() . '/inc/customizer/partial.php';

	// Load validation callback functions.
	require get_template_directory() . '/inc/customizer/validation.php';

	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport  = 'postMessage';

	// Remove the core header textcolor control, as it shares the main text color.
	$wp_customize->remove_control( 'header_textcolor' );

	// Header title color setting and control.
	$wp_customize->add_setting( 'moun10_pro_theme_options[header_title_color]', array(
		'default'           => $options['header_title_color'],
		'sanitize_callback' => 'sanitize_hex_color',
		'transport'			=> 'postMessage'
	) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'moun10_pro_theme_options[header_title_color]', array(
		'priority'			=> 5,
		'label'             => esc_html__( 'Header Title Color', 'moun10-pro' ),
		'section'           => 'colors',
	) ) );

	// Header tagline color setting and control.
	$wp_customize->add_setting( 'moun10_pro_theme_options[header_tagline_color]', array(
		'default'           => $options['header_tagline_color'],
		'sanitize_callback' => 'sanitize_hex_color',
		'transport'			=> 'postMessage'
	) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'moun10_pro_theme_options[header_tagline_color]', array(
		'priority'			=> 6,
		'label'             => esc_html__( 'Header Tagline Color', 'moun10-pro' ),
		'section'           => 'colors',
	) ) );

	// Site identity extra options.
	$wp_customize->add_setting( 'moun10_pro_theme_options[header_txt_logo_extra]', array(
		'default'           => $options['header_txt_logo_extra'],
		'sanitize_callback' => 'moun10_pro_sanitize_select',
		'transport'			=> 'refresh'
	) );

	$wp_customize->add_control( 'moun10_pro_theme_options[header_txt_logo_extra]', array(
		'priority'			=> 50,
		'type'				=> 'radio',
		'label'             => esc_html__( 'Site Identity Extra Options', 'moun10-pro' ),
		'section'           => 'title_tagline',
		'choices'				=> array( 
			'hide-all'     => esc_html__( 'Hide All', 'moun10-pro' ),
			'show-all'     => esc_html__( 'Show All', 'moun10-pro' ),
			'title-only'   => esc_html__( 'Title Only', 'moun10-pro' ),
			'tagline-only' => esc_html__( 'Tagline Only', 'moun10-pro' ),
			'logo-title'   => esc_html__( 'Logo + Title', 'moun10-pro' ),
			'logo-tagline' => esc_html__( 'Logo + Tagline', 'moun10-pro' ),
			)
	) );

	//theme version
	$wp_customize->add_setting( 'moun10_pro_theme_options[theme_version]', array(
		'default'           => $options['theme_version'],
		'sanitize_callback' => 'moun10_pro_sanitize_select',
	) );

	$wp_customize->add_control( 'moun10_pro_theme_options[theme_version]', array(
		'type'    	=> 'radio',
		'label'    	=> esc_html__( 'Theme Version', 'moun10-pro' ),
		'choices'  	=> array(
            'lite-version'   	=> esc_html__( 'Lite Version', 'moun10-pro' ),
            'dark-version'      => esc_html__( 'Dark Version', 'moun10-pro' ),
		),
		'section'  	=> 'colors',
	) );

	/**
	 * Custom colors.
	 */
	$wp_customize->add_setting( 'moun10_pro_theme_options[colorscheme]', array(
		'default'           => $options['colorscheme'],
		'sanitize_callback' => 'moun10_pro_sanitize_select',
	) );

	$wp_customize->add_control( 'moun10_pro_theme_options[colorscheme]', array(
		'type'    => 'radio',
		'label'    => esc_html__( 'Color Scheme', 'moun10-pro' ),
		'choices'  => array(
            'default'   => esc_html__( 'Default', 'moun10-pro' ),
            'blue'      => esc_html__( 'Blue', 'moun10-pro' ),
            'green'     => esc_html__( 'Green', 'moun10-pro' ),
            'red'       => esc_html__( 'Red', 'moun10-pro' ),
            'yellow'    => esc_html__( 'Yellow', 'moun10-pro' ),
            'custom'    => esc_html__( 'Custom', 'moun10-pro' ),
		),
		'section'  => 'colors',
	) );

	$wp_customize->add_setting( 'moun10_pro_theme_options[colorscheme_hue]', array(
		'default'           => $options['colorscheme_hue'],
		'sanitize_callback' => 'sanitize_hex_color', // The hue is stored as a positive integer.
	) );


	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'moun10_pro_theme_options[colorscheme_hue]', array(
		'section'  => 'colors',
	) ) );

	// Add panel for common theme options
	$wp_customize->add_panel( 'moun10_pro_theme_options_panel' , array(
	    'title'      => esc_html__( 'Theme Options','moun10-pro' ),
	    'description'=> esc_html__( 'Moun10 Pro Theme Options.', 'moun10-pro' ),
	    'priority'   => 150,
	) );

	// homepage sortable
	require get_template_directory() . '/inc/customizer/theme-options/sortable.php';

	// loader
	require get_template_directory() . '/inc/customizer/theme-options/loader.php';

	// breadcrumb
	require get_template_directory() . '/inc/customizer/theme-options/breadcrumb.php';

	// excerpt
	require get_template_directory() . '/inc/customizer/theme-options/excerpt.php';

	// typography
	require get_template_directory() . '/inc/customizer/theme-options/typography.php';

	// load layout
	require get_template_directory() . '/inc/customizer/theme-options/layout.php';

	// load menu
	require get_template_directory() . '/inc/customizer/theme-options/menu.php';

	// load archive option
	require get_template_directory() . '/inc/customizer/theme-options/archive.php';
	
	// load single post option
	require get_template_directory() . '/inc/customizer/theme-options/single-posts.php';

	// load pagination option
	require get_template_directory() . '/inc/customizer/theme-options/pagination.php';

	// load footer option
	require get_template_directory() . '/inc/customizer/theme-options/footer.php';

	// load reset option
	require get_template_directory() . '/inc/customizer/theme-options/reset.php';

	// Add panel for front page theme options.
	$wp_customize->add_panel( 'moun10_pro_front_page_panel' , array(
	    'title'      => esc_html__( 'Front Page','moun10-pro' ),
	    'description'=> esc_html__( 'Front Page Theme Options.', 'moun10-pro' ),
	    'priority'   => 140,
	) );

		// Homepage Layout option
		require get_template_directory() . '/inc/customizer/sections/homepage-layout.php';

		// top bar option
		require get_template_directory() . '/inc/customizer/sections/top-bar.php';

	if ( $options['home_layout'] == 'default-design' ) {

		// load slider option
		require get_template_directory() . '/inc/customizer/sections/slider.php';
		
		// load trip-search option
		require get_template_directory() . '/inc/customizer/sections/trip-search.php';
		
		// load about option
		require get_template_directory() . '/inc/customizer/sections/about.php';
		
		// load  popular destination option
		require get_template_directory() . '/inc/customizer/sections/popular-destination.php';
				
		// load featured-product option
		require get_template_directory() . '/inc/customizer/sections/featured-product.php';

		// load features option
		require get_template_directory() . '/inc/customizer/sections/features.php';
		
		// load service option
		require get_template_directory() . '/inc/customizer/sections/service.php';
		
		// load  package option
		require get_template_directory() . '/inc/customizer/sections/package.php';
			
		// load cta option
		require get_template_directory() . '/inc/customizer/sections/cta.php';	

		// load featured package option
		require get_template_directory() . '/inc/customizer/sections/featured-package.php';	

		// load recent-product option
		require get_template_directory() . '/inc/customizer/sections/recent-product.php';
						
		// load counter option
		require get_template_directory() . '/inc/customizer/sections/counter.php';

		// load must read option
		require get_template_directory() . '/inc/customizer/sections/must-read.php';

		// load Team option
		require get_template_directory() . '/inc/customizer/sections/team.php';

		// load  offers option
		require get_template_directory() . '/inc/customizer/sections/offer.php';

		// load  recommended-package option
		require get_template_directory() . '/inc/customizer/sections/recommended-package.php';
		
		// load destination option
		require get_template_directory() . '/inc/customizer/sections/destination.php';

		// load testimonial option
		require get_template_directory() . '/inc/customizer/sections/testimonial.php';

		// load course option
		require get_template_directory() . '/inc/customizer/sections/course.php';

		// load blog option
		require get_template_directory() . '/inc/customizer/sections/blog.php';

		// load subscription option
		require get_template_directory() . '/inc/customizer/sections/subscription.php';
		
	}

	if ( $options['home_layout'] == 'second-design' || $options['home_layout'] == 'seventh-design' ) {

		// load slider option
		require get_template_directory() . '/inc/customizer/sections/slider.php';

		// load about option
		require get_template_directory() . '/inc/customizer/sections/about.php';

		// load service option
		require get_template_directory() . '/inc/customizer/sections/service.php';

		// load destination option
		require get_template_directory() . '/inc/customizer/sections/destination.php';

		// load testimonial option
		require get_template_directory() . '/inc/customizer/sections/testimonial.php';

		// load blog option
		require get_template_directory() . '/inc/customizer/sections/blog.php';

		// load subscription option
		require get_template_directory() . '/inc/customizer/sections/subscription.php';
	}

	if ( $options['home_layout'] == 'third-design' ) {

		// load slider option
		require get_template_directory() . '/inc/customizer/sections/slider.php';

		// load service option
		require get_template_directory() . '/inc/customizer/sections/service.php';

		// load about option
		require get_template_directory() . '/inc/customizer/sections/about.php';

		// load destination option
		require get_template_directory() . '/inc/customizer/sections/destination.php';

		// load subscription option
		require get_template_directory() . '/inc/customizer/sections/subscription.php';

		// load testimonial option
		require get_template_directory() . '/inc/customizer/sections/testimonial.php';

		// load blog option
		require get_template_directory() . '/inc/customizer/sections/blog.php';

	}

	if ( $options['home_layout'] == 'fourth-design' ) {

		// load slider option
		require get_template_directory() . '/inc/customizer/sections/slider.php';

		// load about option
		require get_template_directory() . '/inc/customizer/sections/about.php';
		
		// load featured-product option
		require get_template_directory() . '/inc/customizer/sections/featured-product.php';
					
		// load cta option
		require get_template_directory() . '/inc/customizer/sections/cta.php';	

		// load recent-product option
		require get_template_directory() . '/inc/customizer/sections/recent-product.php';

		// load destination option
		require get_template_directory() . '/inc/customizer/sections/destination.php';

		// load features option
		require get_template_directory() . '/inc/customizer/sections/features.php';

		// load testimonial option
		require get_template_directory() . '/inc/customizer/sections/testimonial.php';

		// load blog option
		require get_template_directory() . '/inc/customizer/sections/blog.php';

		// load subscription option
		require get_template_directory() . '/inc/customizer/sections/subscription.php';

	}

	if ( $options['home_layout'] == 'fifth-design' ) {

		// load slider option
		require get_template_directory() . '/inc/customizer/sections/slider.php';

		// load features option
		require get_template_directory() . '/inc/customizer/sections/features.php';

		// load about option
		require get_template_directory() . '/inc/customizer/sections/about.php';

		// load Team option
		require get_template_directory() . '/inc/customizer/sections/team.php';

		// load counter option
		require get_template_directory() . '/inc/customizer/sections/counter.php';

		// load course option
		require get_template_directory() . '/inc/customizer/sections/course.php';

		// load destination option
		require get_template_directory() . '/inc/customizer/sections/destination.php';

		// load subscription option
		require get_template_directory() . '/inc/customizer/sections/subscription.php';

		// load testimonial option
		require get_template_directory() . '/inc/customizer/sections/testimonial.php';

		// load blog option
		require get_template_directory() . '/inc/customizer/sections/blog.php';

	}

	if ( $options['home_layout'] == 'sixth-design' ) {

		// load slider option
		require get_template_directory() . '/inc/customizer/sections/slider.php';
		
		// load features option
		require get_template_directory() . '/inc/customizer/sections/features.php';

		// load about option
		require get_template_directory() . '/inc/customizer/sections/about.php';
		
		// load must read option
		require get_template_directory() . '/inc/customizer/sections/must-read.php';
		
		// load Team option
		require get_template_directory() . '/inc/customizer/sections/team.php';
		
		// load counter option
		require get_template_directory() . '/inc/customizer/sections/counter.php';

		// load destination option
		require get_template_directory() . '/inc/customizer/sections/destination.php';

		// load subscription option
		require get_template_directory() . '/inc/customizer/sections/subscription.php';

		// load testimonial option
		require get_template_directory() . '/inc/customizer/sections/testimonial.php';

		// load blog option
		require get_template_directory() . '/inc/customizer/sections/blog.php';

	}

}
add_action( 'customize_register', 'moun10_pro_customize_register' );

/*
 * Load customizer sanitization functions.
 */
require get_template_directory() . '/inc/customizer/sanitize.php';

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function moun10_pro_customize_preview_js() {
	wp_enqueue_script( 'moun10-pro-customizer', get_template_directory_uri() . '/assets/js/customizer' . moun10_pro_min() . '.js', array( 'customize-preview' ), '20151215', true );
}
add_action( 'customize_preview_init', 'moun10_pro_customize_preview_js' );

/**
 * Load dynamic logic for the customizer controls area.
 */
function moun10_pro_customize_control_js() {
	// Choose from select jquery.
	wp_enqueue_style( 'chosen-css', get_template_directory_uri() . '/assets/css/chosen' . moun10_pro_min() . '.css' );

	wp_enqueue_script( 'jquery-chosen', get_template_directory_uri() . '/assets/js/chosen.jquery' . moun10_pro_min() . '.js', array( 'jquery' ), '1.4.2', true );

	// simple icon picker
	wp_enqueue_style( 'simple-iconpicker-css', get_template_directory_uri() . '/assets/css/simple-iconpicker' . moun10_pro_min() . '.css' );

	wp_enqueue_style( 'font-awesome-css', get_template_directory_uri() . '/assets/css/font-awesome' . moun10_pro_min() . '.css' );

	wp_enqueue_script( 'jquery-simple-iconpicker', get_template_directory_uri() . '/assets/js/simple-iconpicker' . moun10_pro_min() . '.js', array( 'jquery' ), '', true );

	wp_enqueue_style( 'moun10-pro-customize-controls-css', get_template_directory_uri() . '/assets/css/customize-controls' . moun10_pro_min() . '.css' );

	wp_enqueue_script( 'moun10-pro-customize-controls', get_template_directory_uri() . '/assets/js/customize-controls' . moun10_pro_min() . '.js', array(), '1.0', true );

	$moun10_pro_reset_data = array(
		'reset_message' => esc_html__( 'Refresh the customizer page after saving to view reset effects', 'moun10-pro' )
	);
	// Send list of color variables as object to custom customizer js
	wp_localize_script( 'moun10-pro-customize-controls', 'moun10_pro_reset_data', $moun10_pro_reset_data );
}
add_action( 'customize_controls_enqueue_scripts', 'moun10_pro_customize_control_js' );

if ( !function_exists( 'moun10_pro_reset_options' ) ) :
	/**
	 * Reset all options
	 *
	 * @since Moun10 Pro 1.0.0
	 *
	 * @param bool $checked Whether the reset is checked.
	 * @return bool Whether the reset is checked.
	 */
	function moun10_pro_reset_options() {
		$options = moun10_pro_get_theme_options();
		if ( true === $options['reset_options'] ) {
			// Reset custom theme options.
			set_theme_mod( 'moun10_pro_theme_options', array() );
			// Reset custom header and backgrounds.
			remove_theme_mod( 'header_image' );
			remove_theme_mod( 'header_image_data' );
			remove_theme_mod( 'background_image' );
			remove_theme_mod( 'background_color' );
			remove_theme_mod( 'header_textcolor' );
	    }
	  	else {
		    return false;
	  	}
	}
endif;
add_action( 'customize_save_after', 'moun10_pro_reset_options' );
