<?php
/**
 * Course section
 *
 * This is the template for the content of course section
 *
 * @package Theme Palace
 * @subpackage Moun10 Pro
 * @since Moun10 Pro 1.0.0
 */
if ( ! function_exists( 'moun10_pro_add_course_section' ) ) :
    /**
    * Add course section
    *
    *@since Moun10 Pro 1.0.0
    */
    function moun10_pro_add_course_section() {
        $options = moun10_pro_get_theme_options();
        // Check if course is enabled on frontpage
        $course_enable = apply_filters( 'moun10_pro_section_status', true, 'course_section_enable' );

        if ( !in_array( $options['home_layout'], array( 'default-design', 'fifth-design' ) ) ) {
             $course_enable = false;
        }

        if ( true !== $course_enable ) {
            return false;
        }
        // Get course section details
        $section_details = array();
        $section_details = apply_filters( 'moun10_pro_filter_course_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }
        // Render course section now.
        moun10_pro_render_course_section( $section_details );
    }
endif;

if ( ! function_exists( 'moun10_pro_get_course_section_details' ) ) :
    /**
    * course section details.
    *
    * @since Moun10 Pro 1.0.0
    * @param array $input course section details.
    */
    function moun10_pro_get_course_section_details( $input ) {
        $options = moun10_pro_get_theme_options();

        // Content type.
        $course_content_type  = $options['course_content_type'];
        $course_count = ! empty( $options['course_count'] ) ? $options['course_count'] : 3;
        
        
        $content = array();
        switch ( $course_content_type ) {
            
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $course_count; $i++ ) {
                    if ( ! empty( $options['course_content_page_' . $i] ) )
                        $page_ids[] = $options['course_content_page_' . $i];
                }
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $course_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $course_count; $i++ ) {
                    if ( ! empty( $options['course_content_post_' . $i] ) )
                        $post_ids[] = $options['course_content_post_' . $i];
                }
                
                $args = array(
                    'post_type'             => 'post',
                    'post__in'              => ( array ) $post_ids,
                    'posts_per_page'        => absint( $course_count ),
                    'orderby'               => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['course_content_category'] ) ? $options['course_content_category'] : '';
                $args = array(
                    'post_type'             => 'post',
                    'posts_per_page'        => absint( $course_count ),
                    'cat'                   => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            default:
            break;
        }

        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['url']       = get_the_permalink();
                $page_post['excerpt']   = moun10_pro_trim_content( 25 );
                $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-600x450.jpg';
                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// course section content details.
add_filter( 'moun10_pro_filter_course_section_details', 'moun10_pro_get_course_section_details' );


if ( ! function_exists( 'moun10_pro_render_course_section' ) ) :
  /**
   * Start course section
   *
   * @return string course content
   * @since Moun10 Pro 1.0.0
   *
   */
   function moun10_pro_render_course_section( $content_details = array() ) {
        $options                = moun10_pro_get_theme_options();
        $course_content_type      = $options['course_content_type'];
        if ( empty( $content_details ) ) {
            return;
        } ?>
       <?php ?>
       
       <div id="courses" class="page-section">
                <div class="wrapper">
                    <?php if ( is_customize_preview()): ?>
                        <?php moun10_pro_section_tooltip( 'courses' ); ?>
                    <?php endif ?>
                    <div class="business-section-header">
                        <?php if ( $options['home_layout'] !== 'default-design' ): ?>
                            <?php if( !empty( $options['course_title'] ) ): ?>
                                <h2 class="business-section-title"><?php echo esc_html( $options['course_title'] ); ?></h2>
                            <?php endif;
                            if( !empty( $options['course_sub_title'] ) ):
                             ?>
                                <p class="business-section-subtitle"><?php echo esc_html( $options['course_sub_title'] ); ?></p>
                            <?php endif; ?>
                            <?php else: ?>
                                <?php if( !empty( $options['course_sub_title'] ) ):
                                 ?>
                                    <p class="section-subtitle"><?php echo esc_html( $options['course_sub_title'] ); ?></p>
                                <?php endif; 

                                if( !empty( $options['course_title'] ) ): ?>
                                    <h2 class="section-title"><?php echo esc_html( $options['course_title'] ); ?></h2>
                                <?php endif;  ?>
                        <?php endif ?>
                    
                    </div>

                    <div class="business-section-content col-3">

                    <?php foreach ( $content_details as $content ) : ?>
                        
                        <article class="hentry">
                            <div class="help-wrapper">
                                <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">
                                <a href="<?php echo esc_url( $content['url'] ); ?>" class="post-thumbnail-link"></a>
                                </div><!-- .featured-image -->

                                <div class="entry-container">
                                    <div class="entry-meta">
                                        <span class="cat-links">
                                            <?php the_category( ', ', '', $content['id'] ); ?>
                                        </span>
                                    </div><!-- .entry-meta -->

                                    <header class="entry-header">
                                        <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                    </header>

                                    <div class="entry-content">
                                        <p><?php echo esc_html( $content['excerpt'] ); ?></p>
                                    </div>
                                </div><!-- .entry-container -->
                            </div><!-- .help-wrapper -->
                        </article>

                    <?php endforeach; ?>

                    </div><!-- .section-content -->
                </div><!-- .wrapper -->
            </div><!-- #help-us -->

    <?php }
endif;  ?>
