<?php
/**
 * Call To Action section
 *
 * This is the template for the content of Call To Action section
 *
 * @package Theme Palace
 * @subpackage Moun10 Pro
 * @since Moun10 Pro 1.0.0
 */
if ( ! function_exists( 'moun10_pro_add_cta_section' ) ) :
    /**
    * Add Call To Action section
    *
    *@since Moun10 Pro 1.0.0
    */
    function moun10_pro_add_cta_section() {
        $options = moun10_pro_get_theme_options();
        
        // Check if Call To Action is enabled on frontpage
        $cta_enable = apply_filters( 'moun10_pro_section_status', true, 'cta_section_enable' );

        if ( !in_array( $options['home_layout'], array( 'default-design', 'fourth-design' ) ) ) {
            $cta_enable = false;
        }
        
        if ( true !== $cta_enable ) {
            return false;
        }

        // Get Call To Action section details
        $section_details = array();
        $section_details = apply_filters( 'moun10_pro_filter_cta_section_details', $section_details );
        if ( empty( $section_details ) ) {
            return;
        }

        // Render Call To Action section now.
        moun10_pro_render_cta_section( $section_details[0] );
    }
endif;

if ( ! function_exists( 'moun10_pro_get_cta_section_details' ) ) :
    /**
    * Call To Action section details.
    *
    * @since Moun10 Pro 1.0.0
    * @param array $input Call To Action section details.
    */
    function moun10_pro_get_cta_section_details( $input ) {
        $options = moun10_pro_get_theme_options();

        $cta_content_type  = $options['cta_content_type']; // Call To Action content type
        
        $content = array();
        switch ( $cta_content_type ) {
        	
            case 'page':
                $page_id = ! empty( $options['cta_content_page'] ) ? $options['cta_content_page'] : '';
                $args = array(
                    'post_type'             => 'page',
                    'posts_per_page'        => 1,
                    'p'                     => $page_id,
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'post':
                $page_id = ! empty( $options['cta_content_post'] ) ? $options['cta_content_post'] : '';
                $args = array(
                    'post_type'             => 'post',
                    'p'                     => $page_id,
                    'posts_per_page'        => 1,
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'trip':
                $page_id = ! empty( $options['cta_content_trip'] ) ? $options['cta_content_trip'] : '';

                $args = array(
					'post_type'         => 'itineraries',
					'p'                 => $page_id,
                    'posts_per_page'    => 1,
                    'ignore_sticky_posts'   => true,
                ); 
            break;

            default:
            break;
        }
        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['url']       = get_the_permalink();
                $page_post['excerpt']   = moun10_pro_trim_content( 30 );
                $page_post['image']  	= has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'full' ) : '';

                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;

// Call To Action section content details.
add_filter( 'moun10_pro_filter_cta_section_details', 'moun10_pro_get_cta_section_details' );


if ( ! function_exists( 'moun10_pro_render_cta_section' ) ) :
  /**
   * Start Call To Action section
   *
   * @return string Call To Action content
   * @since Moun10 Pro 1.0.0
   *
   */
   function moun10_pro_render_cta_section( $content_details = array() ) {
        $options    = moun10_pro_get_theme_options();
        $btn_label  = $options['cta_read_more'];
        $sub_title  = $options['cta_sub_title'];

        if ( empty( $content_details ) ) {
            return;
        } ?>

        <div id="call-to-action" class="relative page-section" style="background-image: url(<?php echo $content_details['image']; ?>);">
            <div class="overlay"></div>
            <div class="wrapper">
                 <?php if ( is_customize_preview()): ?>
                      <?php moun10_pro_section_tooltip( 'call-to-action' ); ?>
                  <?php endif ?>
                <header class="section-header">
                    <h2 class="section-title"><?php echo esc_html($content_details['title']); ?></h2>
                    <?php if( !empty($sub_title) ) echo sprintf('<span class="section-subtitle">%s</span>', esc_html($sub_title) ); ?>
                    <?php if($options['cta_content_type'] == 'trip' && class_exists('WP_Travel')) echo wptravel_get_formated_price_currency( WP_Travel_Helpers_Pricings::get_price( array('trip_id'=> $content_details['id']) ) )  ?>
                </header>

                <div class="section-content">
                    <p><?php echo wp_kses_post($content_details['excerpt']); ?></p>
                </div><!-- .section-content -->

                <?php if ( !empty( $btn_label ) ): ?>
                    <div class="read-more">
                        <a href="<?php echo esc_url($content_details['url']); ?>" class="btn"><?php echo esc_html($btn_label); ?></a>
                    </div>
                <?php endif ?>
                
            </div>
        </div><!-- #call-to-action -->  
    <?php }
endif;