<?php
/**
 * Product section
 *
 * This is the template for the content of recent_product section
 *
 * @package Theme Palace
 * @subpackage Moun10 Pro
 * @since Moun10 Pro 1.0.0
 */
if ( ! function_exists( 'moun10_pro_add_recent_product_section' ) ) :
    /**
    * Add recent_product section
    *
    *@since Moun10 Pro 1.0.0
    */
    function moun10_pro_add_recent_product_section() {
    	$options = moun10_pro_get_theme_options();
        // Check if recent_product is enabled on frontpage
        $recent_product_enable = apply_filters( 'moun10_pro_section_status', true, 'recent_product_section_enable' );

        if ( !in_array( $options['home_layout'], array( 'default-design', 'fourth-design' ) ) ) {
            $recent_product_enable = false;
        }

        if ( true !== $recent_product_enable ) {
            return false;
        }
        // Get recent_product section details
        $section_details = array();
        $section_details = apply_filters( 'moun10_pro_filter_recent_product_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }
        if ( !class_exists('WooCommerce') ) {
            return;
        }
        // Render recent_product section now.
        moun10_pro_render_recent_product_section( $section_details );
    }
endif;

if ( ! function_exists( 'moun10_pro_get_recent_product_section_details' ) ) :
    /**
    * recent_product section details.
    *
    * @since Moun10 Pro 1.0.0
    * @param array $input recent_product section details.
    */
    function moun10_pro_get_recent_product_section_details( $input ) {
        $options = moun10_pro_get_theme_options();

        // Content type.
        $recent_product_content_type  = $options['recent_product_content_type'];     
        $recent_product_count = ! empty( $options['recent_product_count'] ) ? $options['recent_product_count'] : 4;
        
        
        $content = array();
        $args = array();
        switch ( $recent_product_content_type ) {


            case 'product':
                $page_ids = array();

                for ( $i = 1; $i <= $recent_product_count; $i++ ) {
                    if ( ! empty( $options['recent_product_content_recent_product_' . $i] ) )
                        $page_ids[] = $options['recent_product_content_recent_product_' . $i];
                }

                $args = array(
                    'post_type'         => 'product',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $recent_product_count ),
                    'orderby'           => 'post__in',
                    );
            break;
            
            case 'product-category':
                $cat_id = ! empty( $options['recent_product_content_recent_product_category'] ) ? $options['recent_product_content_recent_product_category'] : '';

                $args = array(
                'post_type'         => 'product',
                'posts_per_page'    => absint( $recent_product_count ),
                'tax_query'         => array(
                    array(
                        'taxonomy'  => 'product_cat',
                        'field'     => 'id',
                        'terms'     => $cat_id
                    )
                ) );
            break;

            default:
            break;
        }


        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['url']       = get_the_permalink();
                $page_post['excerpt']   = moun10_pro_trim_content( 20 );
                $page_post['image']  	= has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'product-size' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-600x450.jpg';

                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();

        
    
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// recent_product section content details.
add_filter( 'moun10_pro_filter_recent_product_section_details', 'moun10_pro_get_recent_product_section_details' );


if ( ! function_exists( 'moun10_pro_render_recent_product_section' ) ) :
  /**
   * Start recent_product section
   *
   * @return string recent_product content
   * @since Moun10 Pro 1.0.0
   *
   */
   function moun10_pro_render_recent_product_section( $content_details = array() ) {
        $options = moun10_pro_get_theme_options();

        if ( empty( $content_details ) ) {
            return;
        } ?>
      
        <div id="latest-products" class="relative page-section">
            <div class="wrapper">
                <?php if ( is_customize_preview()): ?>
                      <?php moun10_pro_section_tooltip( 'latest-products' ); ?>
                  <?php endif ?>
                <div class="section-header">
                    <p class="section-subtitle"><?php echo esc_html( $options['recent_product_subtitle'] ); ?></p>
                    <h2 class="section-title"><?php echo esc_html( $options['recent_product_title'] ); ?></h2>
                </div><!-- .section-header -->

                <div class="section-content">
                    <ul class="products col-4">
                    <?php foreach ( $content_details as $content ): ?>

                        <li class="product featured-products">
                            <a href="<?php echo esc_url( $content['url'] ) ?>" class="woocommerce-LoopProduct-link woocommerce-loop-product__link">
                                <img src="<?php echo esc_url( $content['image'] ) ?>">
                                <h2 class="woocommerce-loop-product__title"><?php echo esc_html( $content['title'] ) ?></h2>
                                <span class="price">
                                <ins>
                                    <span class="woocommerce-Price-amount amount">
                                        <span class="woocommerce-Price-currencySymbol">
                            
                                            <?php 
                                        $recent_product = new WC_Product( $content['id'] );
                                        echo $recent_product->get_price_html();
                                        ?>
                                        </span>
                                    </span>
                                </ins>
                                </span>
                            </a>
                        </li>
                    <?php endforeach; ?>

                    </ul><!-- .product-slider -->
                </div><!-- .section-content -->
            </div><!-- .wrapper -->
        </div><!-- .latest-products -->

    <?php }
endif;